"use strict";

var saved_details;
var security_info;

function getDomainOwner (certificates, idlevel) {
    if (idlevel <= 1) return "unknown";
    
    let regex = /O=(.*?),[^\s]/;
    let subject = certificates[0].subject;
    return regex.exec(subject)[1].replaceAll("\"", "");
}

function getDomainName (url){
    let split_url = url.split("/")[2].split(".");
    return split_url[split_url.length-2]
	+ "."
	+ split_url[split_url.length-1];
}

function getCertLevel (security_info) {
    return security_info.state !== "secure" ? 0
	: security_info.isExtendedValidation ? 3
	: security_info.certificates[0].subject.includes("O=") ? 2
	: 1;
}

function saveDetails (details){
    saved_details = details;

    let promise = new Promise ((resolve, reject) => {
	resolve(browser.webRequest.getSecurityInfo(details.requestId, {}));
    });

    promise.then(value => {
	security_info = value;
    });

}

browser.webRequest.onHeadersReceived.addListener (
    saveDetails, {
	urls: ["<all_urls>"],
	types: ["main_frame"]
    }, ["blocking"]
);

function replyToContentScript (message) {
    let cert_level = getCertLevel(security_info);
    let domain_name = getDomainName(saved_details.url);
    let domain_owner = getDomainOwner(security_info.certificates, cert_level);

    let data = {
	cert_level: cert_level,
	domain_name: domain_name,
	domain_owner: domain_owner	    
    }

    message === "Yo" ? 	browser.tabs.sendMessage (saved_details.tabId, data)
	: browser.runtime.sendMessage(data)

}

browser.runtime.onMessage.addListener (
    replyToContentScript
);
